@@ -5,9 +5,10 @@ from __future__ import absolute_import, division, print_function
 
 import os
 
-from derrick.core.rigging import Rigging
-from derrick.detectors.image.java import JavaVersionDetector
 from derrick.core.detector_report import DetectorReport
+from derrick.core.rigging import Rigging
+from derrick.detectors.general.image_repo import ImageRepoDetector
+from derrick.detectors.image.java import JavaVersionDetector
 
 RUNTIME = "Maven"
 
@@ -28,4 +29,7 @@ class MavenRigging(Rigging):
         dr = DetectorReport()
         docker_node = dr.create_node("Dockerfile.j2")
         docker_node.register_detector(JavaVersionDetector())
+
+        docker_compose_node = dr.create_node("docker-compose.yml.j2")
+        docker_compose_node.register_detector(ImageRepoDetector())
         return dr.generate_report()
